flutter_xlog_ffi library
Flutter FFI bindings for Tencent mars xlog.
Import this library to initialize the native logger, write log entries, and flush or close xlog from Dart code.
Classes
- FlutterXLog
- Singleton wrapper around the bundled native mars xlog library.